@@ -6,6 +6,8 @@
  * Author: Poul-Henning Kamp <phk@phk.freebsd.dk>
  * Author: Martin Blix Grydeland <martin@varnish-software.com>
  *
+ * SPDX-License-Identifier: BSD-2-Clause
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
@@ -38,7 +40,7 @@
 
 #include "vapi/vsl_int.h"
 
-struct VSM_data;
+struct vsm;
 
 /*
  * enum VSL_tag_e enumerates the SHM log tags, where the identifiers are
@@ -109,9 +111,9 @@ enum VSL_reason_e {
 };
 
 struct VSL_transaction {
-	unsigned		level;
-	int32_t			vxid;
-	int32_t			vxid_parent;
+	int			level;
+	uint32_t		vxid;
+	uint32_t		vxid_parent;
 	enum VSL_transaction_e	type;
 	enum VSL_reason_e	reason;
 	struct VSL_cursor	*c;
@@ -138,6 +140,9 @@ typedef int VSLQ_dispatch_f(struct VSL_data *vsl,
 	 * Return value:
 	 *     0: OK - continue
 	 *   !=0: Makes VSLQ_Dispatch return with this return value immediatly
+	 *
+	 * Return values of the callback function should be distinct from the
+	 * values of enum vsl_status except for 0
 	 */
 
 typedef void VSL_tagfind_f(int tag, void *priv);
@@ -161,6 +166,9 @@ extern const unsigned VSL_tagflags[SLT__MAX];
 	 * Use these macros with VSL_tagflags (included from vsl_int.h):
 	 *
 	 * VSL_tagflags[tag] & SLT_F_BINARY
+	 *   Non-zero if the payload is binary data
+	 *
+	 * VSL_tagflags[tag] & SLT_F_UNSAFE
 	 *   Non-zero if the payload with this tag may include
 	 *   non-printable characters
 	 *
@@ -266,7 +274,7 @@ void VSL_ResetError(struct VSL_data *vsl);
 #define VSL_COPT_TAIL		(1 << 0)
 #define VSL_COPT_BATCH		(1 << 1)
 #define VSL_COPT_TAILSTOP	(1 << 2)
-struct VSL_cursor *VSL_CursorVSM(struct VSL_data *vsl, struct VSM_data *vsm,
+struct VSL_cursor *VSL_CursorVSM(struct VSL_data *vsl, struct vsm *vsm,
     unsigned options);
        /*
 	* Set the cursor pointed to by cursor up as a raw cursor in the
@@ -301,7 +309,8 @@ void VSL_DeleteCursor(const struct VSL_cursor *c);
 	 * Delete the cursor pointed to by c
 	 */
 
-int VSL_ResetCursor(const struct VSL_cursor *c);
+enum vsl_status
+VSL_ResetCursor(const struct VSL_cursor *c);
 	/*
 	 * Reset the cursor position to the head, so that the next call to
 	 * VSL_Next returns the first record. For VSM cursor, it will
@@ -309,10 +318,20 @@ int VSL_ResetCursor(const struct VSL_cursor *c);
 	 * from the tail.
 	 *
 	 * Return values:
-	 *    -1: Operation not supported
+	 * - vsl_end == success
+	 * - and see enum vsl_status
+	 *
 	 */
 
-int VSL_Check(const struct VSL_cursor *c, const struct VSLC_ptr *ptr);
+enum vsl_check {
+	vsl_check_e_notsupp	= -1,
+	vsl_check_e_inval	=  0,
+	vsl_check_warn		=  1,
+	vsl_check_valid		=  2
+};
+
+enum vsl_check
+VSL_Check(const struct VSL_cursor *c, const struct VSLC_ptr *ptr);
 	/*
 	 * Check if the VSLC_ptr structure points to a value that is still
 	 * valid:
@@ -324,17 +343,22 @@ int VSL_Check(const struct VSL_cursor *c, const struct VSLC_ptr *ptr);
 	 *     2: Valid
 	 */
 
-int VSL_Next(const struct VSL_cursor *c);
+enum vsl_status {
+	vsl_e_write	= -5,	// Error from VSL_Write etc.
+	vsl_e_io	= -4,	// I/O read error - see errno
+	vsl_e_overrun	= -3,	// Overrun
+	vsl_e_abandon	= -2,	// Remote abandoned or closed
+	vsl_e_eof	= -1,	// End of file
+	vsl_end		=  0,	// End of log/cursor
+	vsl_more	=  1	// Cursor points to next log record
+};
+
+enum vsl_status
+VSL_Next(const struct VSL_cursor *c);
 	/*
 	 * Return raw pointer to next VSL record.
 	 *
-	 * Return values:
-	 *	1:	Cursor points to next log record
-	 *	0:	End of log
-	 *     -1:	End of file
-	 *     -2:	Remote abandoned or closed
-	 *     -3:	Overrun
-	 *     -4:	I/O read error - see errno
+	 * Return values: see enum vsl_status
 	 */
 
 int VSL_Match(struct VSL_data *vsl, const struct VSL_cursor *c);
@@ -513,7 +537,7 @@ int VSLQ_Dispatch(struct VSLQ *vslq, VSLQ_dispatch_f *func, void *priv);
 	 * Return values:
 	 *     1: Call again
 	 *     0: No more log records available
-	 *   !=0: The error code from VSL_Next() or func returned non-zero
+	 *   !=0: func returned non-zero or enum vsl_status
 	 */
 
 int VSLQ_Flush(struct VSLQ *vslq, VSLQ_dispatch_f *func, void *priv);
